import { ValidationErrors } from '@angular/forms';
export declare namespace FileAttach {
    type LayoutMode = 'default' | 'simple' | 'salaryPortal';
    /**
     * Shorthand for error, e.g. `'FILE_TOO_LARGE'`
     */
    type ErrorType = string | symbol;
    /**
     * Detailed error description, e.g. `'Размер файла превышает 10Мб'`
     */
    type ErrorMessage = string;
    type RequirementConfirmationError = {
        type: ErrorType;
        message: ErrorMessage;
    };
    type RequirementConfirmationResult = {
        status: boolean;
        error?: RequirementConfirmationError;
    };
    type Requirement = {
        /**
         * Текст требования, например, `".pdf до 10Мб"`
         */
        text: string;
        /**
         * Колбэк для проверки того, выполнены ли требования
         *
         * @param newFiles Копия массива файлов которые были добавлены сейчас
         * @param currentFiles Копия массива уже добавленных ранее файлов
         * @returns Объект с полями `status` и `errorMessage`
         */
        isRequirementCompleted?: (newFiles: File[] | FileList, currentFiles: File[] | FileList) => FileAttach.RequirementConfirmationResult;
    };
    type AttachmentDescription = {
        iconURL: string;
        text: string;
    };
    type DetailedDescription = AttachmentDescription[];
    interface ControlValidationErrorsModel extends ValidationErrors {
        fileTooLarge?: boolean;
        incorrectExtension?: boolean;
        tooMuchFiles?: boolean;
        notEnoughFiles?: boolean;
        other?: boolean;
    }
}
